<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\Component\Component;

readonly class AccountTile extends Component
{
    /**
     * @param $imgSrc
     * @return $this
     */
    public function src($imgSrc): static
    {
        return $this->setProperty('imgSrc', $imgSrc);
    }

    /**
     * @param $name
     * @return $this
     */
    public function name($name): static
    {
        return $this->setProperty('name', $name);
    }

    /**
     * @param $role
     * @return $this
     */
    public function role($role): static
    {
        return $this->setProperty('role', $role);
    }
}
