<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\Component\Component;

/**
 * @type Component
 * Class ThePageContent
 * @package apexl\Io\modules\display\components
 */
readonly class ThePageContent extends Component
{
}
