<?php

namespace apexl\Io\modules\display\components;

use apexl\Io\modules\component\Component\Component;

readonly class Iframe extends Component
{
    public function __construct()
    {
        parent::__construct();
        $this->addClass('button-link');
    }

    public function setSrc($url)
    {
        $this->setProperty('src', $url);
        return $this;
    }

    public function setTitle($title)
    {
        $this->setProperty('title', $title);
        return $this;
    }
}
